@@ -512,8 +512,9 @@ MagickPrivate char **NTArgvToUTF8(const int argc,wchar_t **argv)
 */
 MagickPrivate int NTCloseDirectory(DIR *entry)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(entry != (DIR *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   FindClose(entry->hSearch);
   entry=(DIR *) RelinquishMagickMemory(entry);
   return(0);
@@ -1328,6 +1329,8 @@ MagickPrivate const GhostInfo *NTGhostscriptDLLVectors(void)
   ghost_info.new_instance=NTGhostscriptNewInstance;
   ghost_info.run_string=(int (MagickDLLCall *)(gs_main_instance *,const char *,
     int,int *)) (lt_dlsym(ghost_handle,"gsapi_run_string"));
+  ghost_info.set_arg_encoding=(int (MagickDLLCall*)(gs_main_instance*, int)) (
+    lt_dlsym(ghost_handle, "gsapi_set_arg_encoding"));
   ghost_info.set_stdio=(int (MagickDLLCall *)(gs_main_instance *,int(
     MagickDLLCall *)(void *,char *,int),int(MagickDLLCall *)(void *,
     const char *,int),int(MagickDLLCall *)(void *,const char *,int)))
@@ -2081,7 +2084,8 @@ MagickPrivate unsigned char *NTResourceToBlob(const char *id)
     *value;
 
   assert(id != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",id);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",id);
 #ifdef MAGICKCORE_LIBRARY_NAME
   handle=GetModuleHandle(MAGICKCORE_LIBRARY_NAME);
 #else
