@@ -36,9 +36,7 @@ extern ModuleExport size_t
   RegisterAAIImage(void),
   RegisterARTImage(void),
   RegisterASHLARImage(void),
-  RegisterAVIImage(void),
   RegisterAVSImage(void),
-  RegisterBIEImage(void),
   RegisterBGRImage(void),
   RegisterBMPImage(void),
   RegisterBRAILLEImage(void),
@@ -52,7 +50,6 @@ extern ModuleExport size_t
   RegisterCUBEImage(void),
   RegisterCUTImage(void),
   RegisterDCMImage(void),
-  RegisterDCXImage(void),
   RegisterDDSImage(void),
   RegisterDEBUGImage(void),
   RegisterDIBImage(void),
@@ -61,12 +58,6 @@ extern ModuleExport size_t
   RegisterDPSImage(void),
   RegisterDPXImage(void),
   RegisterEMFImage(void),
-  RegisterEPDFImage(void),
-  RegisterEPIImage(void),
-  RegisterEPSImage(void),
-  RegisterEPS2Image(void),
-  RegisterEPSFImage(void),
-  RegisterEPSIImage(void),
   RegisterEPTImage(void),
   RegisterEXRImage(void),
   RegisterFARBFELDImage(void),
@@ -76,25 +67,19 @@ extern ModuleExport size_t
   RegisterFLIFImage(void),
   RegisterFPXImage(void),
   RegisterFTXTImage(void),
-  RegisterG3Image(void),
   RegisterGIFImage(void),
-  RegisterGIF87Image(void),
   RegisterGRADIENTImage(void),
-  RegisterGRANITEImage(void),
   RegisterGRAYImage(void),
   RegisterHALDImage(void),
   RegisterHDRImage(void),
   RegisterHEICImage(void),
-  RegisterHImage(void),
   RegisterHISTOGRAMImage(void),
   RegisterHRZImage(void),
   RegisterHTMLImage(void),
-  RegisterICBImage(void),
   RegisterICONImage(void),
   RegisterINFOImage(void),
   RegisterINLINEImage(void),
   RegisterIPLImage(void),
-  RegisterJBGImage(void),
   RegisterJBIGImage(void),
   RegisterJNXImage(void),
   RegisterJPEGImage(void),
@@ -110,51 +95,38 @@ extern ModuleExport size_t
   RegisterMATTEImage(void),
   RegisterMETAImage(void),
   RegisterMIFFImage(void),
-  RegisterMNGImage(void),
   RegisterMONOImage(void),
   RegisterMPCImage(void),
   RegisterMPRImage(void),
   RegisterMSLImage(void),
   RegisterMTVImage(void),
   RegisterMVGImage(void),
-  RegisterNETSCAPEImage(void),
   RegisterNULLImage(void),
-  RegisterP7Image(void),
-  RegisterPBMImage(void),
   RegisterORAImage(void),
   RegisterOTBImage(void),
   RegisterPALMImage(void),
   RegisterPANGOImage(void),
   RegisterPATTERNImage(void),
   RegisterPCDImage(void),
-  RegisterPCDSImage(void),
   RegisterPCLImage(void),
-  RegisterPCTImage(void),
   RegisterPCXImage(void),
   RegisterPDBImage(void),
   RegisterPDFImage(void),
   RegisterPESImage(void),
   RegisterPGXImage(void),
-  RegisterPICImage(void),
   RegisterPICTImage(void),
   RegisterPIXImage(void),
-  RegisterPGMImage(void),
   RegisterPLASMAImage(void),
-  RegisterPMImage(void),
   RegisterPNGImage(void),
   RegisterPNMImage(void),
-  RegisterPPMImage(void),
   RegisterPSImage(void),
   RegisterPS2Image(void),
   RegisterPS3Image(void),
   RegisterPSDImage(void),
-  RegisterPTIFImage(void),
   RegisterPWPImage(void),
   RegisterQOIImage(void),
-  RegisterRASImage(void),
   RegisterRAWImage(void),
   RegisterRGBImage(void),
-  RegisterRGBAImage(void),
   RegisterRGFImage(void),
   RegisterRLAImage(void),
   RegisterRLEImage(void),
@@ -163,16 +135,13 @@ extern ModuleExport size_t
   RegisterSCTImage(void),
   RegisterSFWImage(void),
   RegisterSGIImage(void),
-  RegisterSHTMLImage(void),
   RegisterSIXELImage(void),
   RegisterSTEGANOImage(void),
   RegisterSTRIMGImage(void),
   RegisterSUNImage(void),
   RegisterSVGImage(void),
-  RegisterTEXTImage(void),
   RegisterTGAImage(void),
   RegisterTHUMBNAILImage(void),
-  RegisterTIFImage(void),
   RegisterTIFFImage(void),
   RegisterTILEImage(void),
   RegisterTIMImage(void),
@@ -182,13 +151,11 @@ extern ModuleExport size_t
   RegisterUILImage(void),
   RegisterURLImage(void),
   RegisterUYVYImage(void),
-  RegisterVDAImage(void),
   RegisterVICARImage(void),
   RegisterVIDImage(void),
   RegisterVIDEOImage(void),
   RegisterVIFFImage(void),
   RegisterVIPSImage(void),
-  RegisterVSTImage(void),
   RegisterWBMPImage(void),
   RegisterWEBPImage(void),
   RegisterWMFImage(void),
@@ -199,7 +166,6 @@ extern ModuleExport size_t
   RegisterXCFImage(void),
   RegisterXPMImage(void),
   RegisterXPSImage(void),
-  RegisterXVImage(void),
   RegisterXWDImage(void),
   RegisterYAMLImage(void),
   RegisterYCBCRImage(void),
@@ -209,9 +175,7 @@ extern ModuleExport void
   UnregisterAAIImage(void),
   UnregisterARTImage(void),
   UnregisterASHLARImage(void),
-  UnregisterAVIImage(void),
   UnregisterAVSImage(void),
-  UnregisterBIEImage(void),
   UnregisterBGRImage(void),
   UnregisterBMPImage(void),
   UnregisterBRAILLEImage(void),
@@ -225,7 +189,6 @@ extern ModuleExport void
   UnregisterCUBEImage(void),
   UnregisterCUTImage(void),
   UnregisterDCMImage(void),
-  UnregisterDCXImage(void),
   UnregisterDDSImage(void),
   UnregisterDEBUGImage(void),
   UnregisterDIBImage(void),
@@ -234,12 +197,6 @@ extern ModuleExport void
   UnregisterDPSImage(void),
   UnregisterDPXImage(void),
   UnregisterEMFImage(void),
-  UnregisterEPDFImage(void),
-  UnregisterEPIImage(void),
-  UnregisterEPSImage(void),
-  UnregisterEPS2Image(void),
-  UnregisterEPSFImage(void),
-  UnregisterEPSIImage(void),
   UnregisterEPTImage(void),
   UnregisterEXRImage(void),
   UnregisterFARBFELDImage(void),
@@ -249,25 +206,19 @@ extern ModuleExport void
   UnregisterFLIFImage(void),
   UnregisterFPXImage(void),
   UnregisterFTXTImage(void),
-  UnregisterG3Image(void),
   UnregisterGIFImage(void),
-  UnregisterGIF87Image(void),
   UnregisterGRADIENTImage(void),
-  UnregisterGRANITEImage(void),
   UnregisterGRAYImage(void),
   UnregisterHALDImage(void),
   UnregisterHDRImage(void),
   UnregisterHEICImage(void),
-  UnregisterHImage(void),
   UnregisterHISTOGRAMImage(void),
   UnregisterHRZImage(void),
   UnregisterHTMLImage(void),
-  UnregisterICBImage(void),
   UnregisterICONImage(void),
   UnregisterINFOImage(void),
   UnregisterINLINEImage(void),
   UnregisterIPLImage(void),
-  UnregisterJBGImage(void),
   UnregisterJBIGImage(void),
   UnregisterJNXImage(void),
   UnregisterJPEGImage(void),
@@ -275,7 +226,6 @@ extern ModuleExport void
   UnregisterJSONImage(void),
   UnregisterJXLImage(void),
   UnregisterLABELImage(void),
-  UnregisterLOCALEImage(void),
   UnregisterMACImage(void),
   UnregisterMAGICKImage(void),
   UnregisterMAPImage(void),
@@ -284,51 +234,38 @@ extern ModuleExport void
   UnregisterMATTEImage(void),
   UnregisterMETAImage(void),
   UnregisterMIFFImage(void),
-  UnregisterMNGImage(void),
   UnregisterMONOImage(void),
   UnregisterMPCImage(void),
   UnregisterMPRImage(void),
   UnregisterMSLImage(void),
   UnregisterMTVImage(void),
   UnregisterMVGImage(void),
-  UnregisterNETSCAPEImage(void),
   UnregisterNULLImage(void),
-  UnregisterP7Image(void),
-  UnregisterPBMImage(void),
   UnregisterORAImage(void),
   UnregisterOTBImage(void),
   UnregisterPALMImage(void),
   UnregisterPANGOImage(void),
   UnregisterPATTERNImage(void),
   UnregisterPCDImage(void),
-  UnregisterPCDSImage(void),
   UnregisterPCLImage(void),
-  UnregisterPCTImage(void),
   UnregisterPCXImage(void),
   UnregisterPDBImage(void),
   UnregisterPDFImage(void),
   UnregisterPESImage(void),
   UnregisterPGXImage(void),
-  UnregisterPICImage(void),
   UnregisterPICTImage(void),
   UnregisterPIXImage(void),
   UnregisterPLASMAImage(void),
-  UnregisterPGMImage(void),
-  UnregisterPMImage(void),
   UnregisterPNGImage(void),
   UnregisterPNMImage(void),
-  UnregisterPPMImage(void),
   UnregisterPSImage(void),
   UnregisterPS2Image(void),
   UnregisterPS3Image(void),
   UnregisterPSDImage(void),
-  UnregisterPTIFImage(void),
   UnregisterPWPImage(void),
   UnregisterQOIImage(void),
-  UnregisterRASImage(void),
   UnregisterRAWImage(void),
   UnregisterRGBImage(void),
-  UnregisterRGBAImage(void),
   UnregisterRGFImage(void),
   UnregisterRLAImage(void),
   UnregisterRLEImage(void),
@@ -337,16 +274,13 @@ extern ModuleExport void
   UnregisterSCTImage(void),
   UnregisterSFWImage(void),
   UnregisterSGIImage(void),
-  UnregisterSHTMLImage(void),
   UnregisterSIXELImage(void),
   UnregisterSTEGANOImage(void),
   UnregisterSTRIMGImage(void),
   UnregisterSUNImage(void),
   UnregisterSVGImage(void),
-  UnregisterTEXTImage(void),
   UnregisterTGAImage(void),
   UnregisterTHUMBNAILImage(void),
-  UnregisterTIFImage(void),
   UnregisterTIFFImage(void),
   UnregisterTILEImage(void),
   UnregisterTIMImage(void),
@@ -356,13 +290,11 @@ extern ModuleExport void
   UnregisterUILImage(void),
   UnregisterURLImage(void),
   UnregisterUYVYImage(void),
-  UnregisterVDAImage(void),
   UnregisterVICARImage(void),
   UnregisterVIDImage(void),
   UnregisterVIDEOImage(void),
   UnregisterVIFFImage(void),
   UnregisterVIPSImage(void),
-  UnregisterVSTImage(void),
   UnregisterWBMPImage(void),
   UnregisterWEBPImage(void),
   UnregisterWMFImage(void),
@@ -373,7 +305,6 @@ extern ModuleExport void
   UnregisterXCFImage(void),
   UnregisterXPMImage(void),
   UnregisterXPSImage(void),
-  UnregisterXVImage(void),
   UnregisterXWDImage(void),
   UnregisterYAMLImage(void),
   UnregisterYCBCRImage(void),
